lyricstools.Lyrics
==================

.. inheritance-diagram:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics
   :private-bases:

.. autoclass:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics

Read-only Properties
--------------------

.. autoattribute:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.contents_duration

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.duration_in_seconds

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.engraver_consists

    Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

.. autoattribute:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.engraver_removals

    Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

.. autoattribute:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.format

    Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

.. autoattribute:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.is_semantic

    Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

.. autoattribute:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.leaves

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.music

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.override

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.parent

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.preprolated_duration

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.prolated_duration

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.prolation

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.set

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.spanners

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.start_offset

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.start_offset_in_seconds

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.stop_offset

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. autoattribute:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.stop_offset_in_seconds

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

Read/write Properties
---------------------

.. autoattribute:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.context_name

    Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

.. autoattribute:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.is_nonsemantic

    Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

.. autoattribute:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.is_parallel

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. autoattribute:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.name

    Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

Methods
-------

.. automethod:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.append

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.extend

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.index

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.insert

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.pop

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.remove

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

Special Methods
---------------

.. automethod:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.__add__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.__contains__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.__delattr__

    Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.__delitem__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.__eq__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.__ge__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.__getitem__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.__gt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.__hash__

    Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.__iadd__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.__imul__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.__le__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.__len__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.__lt__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.__mul__

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.__ne__

    Inherited from :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

.. automethod:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.__radd__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.__repr__

    Inherited from :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

.. automethod:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.__rmul__

    Inherited from :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

.. automethod:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.__setattr__

    Inherited from `__builtin__.object`

.. automethod:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.__setitem__

    Inherited from :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

.. automethod:: abjad.tools.lyricstools.Lyrics.Lyrics.Lyrics.__str__

    Inherited from `__builtin__.object`
